===============================
passwordmetrics
===============================

.. image:: https://badge.fury.io/py/passwordmetrics.png
    :target: http://badge.fury.io/py/passwordmetrics

.. image:: https://travis-ci.org/regebro/passwordmetrics.png?branch=master
        :target: https://travis-ci.org/regebro/passwordmetrics

.. image:: https://pypip.in/d/passwordmetrics/badge.png
        :target: https://pypi.python.org/pypi/passwordmetrics


Checking the entropy of a password. Useful in password checkers.

* Free software: BSD license
* Documentation: http://passwordmetrics.readthedocs.org.


Features
--------

passwordmetrics will return information about a password, such as length,
words found, what types of characters that are used, and a metric called
"entropy" which will give an approximate measure of how hard the password
is to guess.

